==> analytics-2.4.1601.1-sources.jar: com/zing/zalo/zalosdk/analytics/internal/h.java <==
package com.zing.zalo.zalosdk.analytics.internal;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.app.Application;
import android.app.Application.ActivityLifecycleCallbacks;
import android.os.Bundle;
import android.os.Handler;
import com.zing.zalo.zalosdk.core.helper.Utils;
import java.lang.ref.WeakReference;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;

@SuppressLint({"NewApi"})
public class h {
    public static final String a = h.class.getSimpleName();
    private static h b;
    private static b h;
    private boolean c = false;
    private boolean d = true;
    private Handler e = new Handler();
    private List<a> f = new CopyOnWriteArrayList();
    private Runnable g;

    public interface a {
        void a(WeakReference<Activity> weakReference);

        void b(WeakReference<Activity> weakReference);

        void c(WeakReference<Activity> weakReference);
    }

    class b implements ActivityLifecycleCallbacks {
        final /* synthetic */ h a;

        public b(h hVar) {
            this.a = hVar;
        }

        public void onActivityCreated(Activity activity, Bundle bundle) {
        }

        public void onActivityDestroyed(Activity activity) {
        }

        public void onActivityPaused(Activity activity) {
            h.b.b(activity);
        }

        public void onActivityResumed(Activity activity) {
            h.b.a(activity);
        }

        public void onActivitySaveInstanceState(Activity activity, Bundle bundle) {
        }

        public void onActivityStarted(Activity activity) {
        }

        public void onActivityStopped(Activity activity) {
        }
    }

    protected h() {
        if (!Utils.belowSandwich()) {
            h = new b(this);
        }
    }

    public static h a(Application application) {
        if (b == null) {
            b = new h();
            if (!Utils.belowSandwich()) {
                application.registerActivityLifecycleCallbacks(h);
            }
        }
        return b;
    }

    public static h b(Application application) {
        if (b == null) {
            a(application);
        }
        return b;
    }

    public void a(Activity activity) {
        boolean z = false;
        this.d = false;
        if (!this.c) {
            z = true;
        }
        this.c = true;
        if (this.g != null) {
            this.e.removeCallbacks(this.g);
        }
        WeakReference weakReference = new WeakReference(activity);
        if (z) {
            for (a a : this.f) {
                try {
                    a.a(weakReference);
                } catch (Exception e) {
                }
            }
        }
        for (a a2 : this.f) {
            try {
                a2.c(weakReference);
            } catch (Exception e2) {
            }
        }
    }

    public void a(a aVar) {
        if (!this.f.contains(aVar)) {
            this.f.add(aVar);
        }
    }

    public void b(Activity activity) {
        this.d = true;
        if (this.g != null) {
            this.e.removeCallbacks(this.g);
        }
        final WeakReference weakReference = new WeakReference(activity);
        Handler handler = this.e;
        Runnable anonymousClass1 = new Runnable(this) {
            final /* synthetic */ h b;

            public void run() {
                if (this.b.c && this.b.d) {
                    this.b.c = false;
                    for (a b : this.b.f) {
                        try {
                            b.b(weakReference);
                        } catch (Exception e) {
                        }
                    }
                }
            }
        };
        this.g = anonymousClass1;
        handler.postDelayed(anonymousClass1, 500);
    }
}

==> analytics-2.4.2501.1-sources.jar: com/zing/zalo/zalosdk/analytics/internal/h.java <==
package com.zing.zalo.zalosdk.analytics.internal;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.app.Application;
import android.app.Application.ActivityLifecycleCallbacks;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import com.zing.zalo.zalosdk.core.helper.Utils;
import java.lang.ref.WeakReference;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;

@SuppressLint({"NewApi"})
public class h {
    public static final String a = h.class.getSimpleName();
    private static h b;
    private static b h;
    private boolean c = false;
    private boolean d = true;
    private Handler e = new Handler(Looper.getMainLooper());
    private List<a> f = new CopyOnWriteArrayList();
    private Runnable g;

    public interface a {
        void a(WeakReference<Activity> weakReference);

        void b(WeakReference<Activity> weakReference);

        void c(WeakReference<Activity> weakReference);
    }

    class b implements ActivityLifecycleCallbacks {
        final /* synthetic */ h a;

        public b(h hVar) {
            this.a = hVar;
        }

        public void onActivityCreated(Activity activity, Bundle bundle) {
        }

        public void onActivityDestroyed(Activity activity) {
        }

        public void onActivityPaused(Activity activity) {
            h.b.b(activity);
        }

        public void onActivityResumed(Activity activity) {
            h.b.a(activity);
        }

        public void onActivitySaveInstanceState(Activity activity, Bundle bundle) {
        }

        public void onActivityStarted(Activity activity) {
        }

        public void onActivityStopped(Activity activity) {
        }
    }

    protected h() {
        if (!Utils.belowSandwich()) {
            h = new b(this);
        }
    }

    public static h a(Application application) {
        if (b == null) {
            b = new h();
            if (!Utils.belowSandwich()) {
                application.registerActivityLifecycleCallbacks(h);
            }
        }
        return b;
    }

    public static h b(Application application) {
        if (b == null) {
            a(application);
        }
        return b;
    }

    public void a(Activity activity) {
        boolean z = false;
        this.d = false;
        if (!this.c) {
            z = true;
        }
        this.c = true;
        if (this.g != null) {
            this.e.removeCallbacks(this.g);
        }
        WeakReference weakReference = new WeakReference(activity);
        if (z) {
            for (a a : this.f) {
                try {
                    a.a(weakReference);
                } catch (Exception e) {
                }
            }
        }
        for (a a2 : this.f) {
            try {
                a2.c(weakReference);
            } catch (Exception e2) {
            }
        }
    }

    public void a(a aVar) {
        if (!this.f.contains(aVar)) {
            this.f.add(aVar);
        }
    }

    public void b(Activity activity) {
        this.d = true;
        if (this.g != null) {
            this.e.removeCallbacks(this.g);
        }
        final WeakReference weakReference = new WeakReference(activity);
        Handler handler = this.e;
        Runnable anonymousClass1 = new Runnable(this) {
            final /* synthetic */ h b;

            public void run() {
                if (this.b.c && this.b.d) {
                    this.b.c = false;
                    for (a b : this.b.f) {
                        try {
                            b.b(weakReference);
                        } catch (Exception e) {
                        }
                    }
                }
            }
        };
        this.g = anonymousClass1;
        handler.postDelayed(anonymousClass1, 500);
    }
}
